### Name: VGAM-package
### Title: Vector Generalized Linear and Additive Models
### Aliases: VGAM-package VGAM
### Keywords: package models regression

### ** Examples

# Fit the proportional odds model, p.179, in McCullagh and Nelder (1989)
data(pneumo)
pneumo = transform(pneumo, let=log(exposure.time))
(fit = vglm(cbind(normal, mild, severe) ~ let,
            cumulative(parallel=TRUE, reverse=TRUE), pneumo))
fit@y   # Sample proportions
weights(fit, type="prior")   # Number of observations
coef(fit, matrix=TRUE)
constraints(fit)   # Constraint matrices

# Fit a two species GAM simultaneously
data(hunua)
fit2 = vgam(cbind(agaaus, kniexc) ~ s(altitude),
            fam = binomialff(mv=TRUE), hunua)
coef(fit2, mat=TRUE)   # Not really interpretable
## Not run: 
##D plot(fit2, se=TRUE, overlay=TRUE, lcol=1:2, scol=1:2)
##D attach(hunua)
##D o = order(altitude)
##D matplot(altitude[o], fitted(fit2)[o,], type="l", lwd=2, las=1,
##D     xlab="Altitude (m)", ylab="Probability of presence",
##D     main="Two plant species' response curves", ylim=c(0,.8))
##D rug(altitude)
##D detach(hunua)
## End(Not run)


# LMS quantile regression
data(bminz)
fit = vgam(BMI ~ s(age, df=c(4,2)), fam=lms.bcn(zero=1), data=bminz, tr=TRUE)
predict(fit)[1:3,]
fitted(fit)[1:3,]
bminz[1:3,]
# Person 1 is near the lower quartile of BMI amongst people his age
cdf(fit)[1:3]

## Not run: 
##D # Quantile plot
##D par(bty="l", mar=c(5,4,4,3)+0.1, xpd=TRUE)
##D qtplot(fit, percentiles=c(5,50,90,99), main="Quantiles",
##D        xlim=c(15,90), las=1, ylab="BMI", lwd=2, lcol=4)
##D 
##D # Density plot
##D ygrid = seq(15, 43, len=100)  # BMI ranges
##D par(mfrow=c(1,1), lwd=2)
##D a = deplot(fit, x0=20, y=ygrid, xlab="BMI", col="black",
##D     main="Density functions at Age = 20 (black), 42 (red) and 55 (blue)")
##D a
##D a = deplot(fit, x0=42, y=ygrid, add=TRUE, llty=2, col="red")
##D a = deplot(fit, x0=55, y=ygrid, add=TRUE, llty=4, col="blue", Attach=TRUE)
##D a@post$deplot  # Contains density function values
## End(Not run)

# GEV distribution for extremes
data(oxtemp)
(fit = vglm(maxtemp ~ 1, egev, data=oxtemp, trace=TRUE))
fitted(fit)[1:3,]
coef(fit, mat=TRUE)
Coef(fit)
vcov(fit)
vcov(fit, untransform=TRUE)
sqrt(diag(vcov(fit)))   # Approximate standard errors
## Not run:  rlplot(fit) 



