### Name: betabinomial
### Title: Beta-binomial Distribution Family Function
### Aliases: betabinomial
### Keywords: models regression

### ** Examples

# Example 1
N = 10; mu = 0.5; rho = 0.8 
y = rbetabin(n=100, size=N, prob=mu, rho=rho)
fit = vglm(cbind(y,N-y) ~ 1, betabinomial, trace=TRUE)
coef(fit, matrix=TRUE)
Coef(fit)
cbind(fit@y, weights(fit, type="prior"))[1:5,]

# Example 2
data(lirat)
fit = vglm(cbind(R,N-R) ~ 1, betabinomial, data=lirat,
           trace=TRUE, subset=N>1)
coef(fit, matrix=TRUE)
Coef(fit)
t(fitted(fit))
t(fit@y)
t(weights(fit, type="prior"))

# Example 3, which is more complicated
lirat = transform(lirat, fgrp = factor(grp))
summary(lirat)   # Only 5 litters in group 3
fit2 = vglm(cbind(R,N-R) ~ fgrp + hb, betabinomial(zero=2),
           data=lirat, trace=TRUE, subset=N>1)
coef(fit2, matrix=TRUE)
## Not run: 
##D plot(lirat$hb[lirat$N>1], fit2@misc$rho,
##D      xlab="Hemoglobin", ylab="Estimated rho",
##D      pch=as.character(lirat$grp[lirat$N>1]),
##D      col=lirat$grp[lirat$N>1])
## End(Not run)
## Not run: 
##D data(lirat)
##D attach(lirat)
##D # cf. Figure 3 of Moore and Tsiatis (1991)
##D plot(hb, R/N, pch=as.character(grp), col=grp, las=1,
##D      xlab="Hemoglobin level", ylab="Proportion Dead",
##D      main="Fitted values (lines)")
##D detach(lirat)
##D 
##D smalldf = lirat[lirat$N>1,]
##D for(gp in 1:4) {
##D     xx = smalldf$hb[smalldf$grp==gp]
##D     yy = fitted(fit2)[smalldf$grp==gp]
##D     o = order(xx)
##D     lines(xx[o], yy[o], col=gp)
##D }
## End(Not run)



