### Name: cgumbel
### Title: Censored Gumbel Distribution
### Aliases: cgumbel
### Keywords: models regression

### ** Examples

# Example 1
data(venice)
ystar = venice[["r1"]]  # Use the first order statistic as the response
n = length(ystar)
L = runif(n, 100, 104) # Lower censoring points
U = runif(n, 130, 135) # Upper censoring points
y = pmax(L, ystar) # Left  censored
y = pmin(U, y)     # Right censored
extra = list(leftcensored = ystar < L, rightcensored = ystar > U)
fit = vglm(y ~ scale(year), data=venice, trace=TRUE, extra=extra,
           cgumbel(mean=FALSE, perc=c(5,25,50,75,95)))
coef(fit, matrix=TRUE)
fitted(fit)[1:5,]
fit@extra

# Example 2: simulated data
n = 1000
ystar = rgumbel(n, loc=1, scale=exp(0.5)) # The uncensored data
L = runif(n, -1, 1) # Lower censoring points
U = runif(n,  2, 5) # Upper censoring points
y = pmax(L, ystar) # Left  censored
y = pmin(U, y)     # Right censored
## Not run: par(mfrow=c(1,2)); hist(ystar); hist(y);
extra = list(leftcensored = ystar < L, rightcensored = ystar > U)
fit = vglm(y ~ 1, trace=TRUE, extra=extra, cgumbel)
coef(fit, matrix=TRUE)



