### Name: lms.bcg
### Title: LMS Quantile Regression with a Box-Cox transformation to a Gamma
###   Distribution
### Aliases: lms.bcg
### Keywords: models regression

### ** Examples

data(bminz)

# This converges, but can't be deplot()'ed or qtplot()'ed
fit = vglm(BMI ~ bs(age, df=4), fam=lms.bcg(zero=c(1,3)), data=bminz, tr=TRUE)
coef(fit, matrix=TRUE)
## Not run: 
##D par(mfrow=c(1,1))
##D plotvgam(fit, se=TRUE) # Plot mu function (only)
## End(Not run)

# Difficult to get a model that converges
# Here, we prematurely stop iterations because it fails near the solution
fit = vgam(BMI ~ s(age, df=c(4,2)), maxit=4,
           fam=lms.bcg(zero=1, init.lam=3), data=bminz, tr=TRUE)

predict(fit)[1:3,]
fitted(fit)[1:3,]
bminz[1:3,]
# Person 1 is near the lower quartile of BMI amongst people his age
cdf(fit)[1:3]

## Not run: 
##D # Quantile plot
##D par(bty="l", mar=c(5,4,4,3)+0.1, xpd=TRUE)
##D qtplot(fit, percentiles=c(5,50,90,99), main="Quantiles",
##D        xlim=c(15,90), las=1, ylab="BMI", lwd=2, lcol=4)
##D 
##D # Density plot
##D ygrid = seq(15, 43, len=100)  # BMI ranges
##D par(mfrow=c(1,1), lwd=2)
##D a = deplot(fit, x0=20, y=ygrid, xlab="BMI", col="black",
##D     main="Density functions at Age = 20 (black), 42 (red) and 55 (blue)")
##D a
##D a = deplot(fit, x0=42, y=ygrid, add=TRUE, llty=2, col="red")
##D a = deplot(fit, x0=55, y=ygrid, add=TRUE, llty=4, col="blue", Attach=TRUE)
##D a@post$deplot  # Contains density function values
## End(Not run)



