### Name: nbolf
### Title: Negative Binomial-Ordinal Link Function
### Aliases: nbolf
### Keywords: math models regression

### ** Examples

nbolf("prob", short=FALSE)
nbolf("prob", tag=TRUE)

p = seq(0.02, 0.98, by=0.01)
earg = list(cutpoint=2, k=1)
y = nbolf(p, earg=earg)
y. = nbolf(p, earg=earg, deriv=1)
max(abs(nbolf(y, earg=earg, inv=TRUE) - p)) # Should be 0

## Not run: 
##D par(mfrow=c(2,1), las=1)
##D plot(p, y, type="l", col="blue", main="nbolf()")
##D abline(h=0, v=0.5, col="red", lty="dashed")
##D 
##D plot(p, y., type="l", col="blue",
##D      main="(Reciprocal of) first NBOLF derivative")
## End(Not run)

# Another example
nn = 1000
x2 = sort(runif(nn))
x3 = runif(nn)
mymu = exp( 3 + 1 * x2 - 2 * x3)
k = 4
y1 = rnbinom(nn, mu=mymu, size=k)
cutpoints = c(-Inf, 10, 20, Inf)
cuty = Cut(y1, breaks=cutpoints)
## Not run: 
##D plot(x2, x3, col=cuty, pch=as.character(cuty))
## End(Not run)
table(cuty) / sum(table(cuty))
fit = vglm(cuty ~ x2 + x3, fam = cumulative(link="nbolf",
           reverse=TRUE, parallel=TRUE, intercept.apply=TRUE,
           mv=TRUE, earg=list(cutpoint=cutpoints[2:3], k=k)),
           trace=TRUE)
fit@y[1:5,]
fitted(fit)[1:5,]
predict(fit)[1:5,]
coef(fit)
coef(fit, matrix=TRUE)
constraints(fit)
fit@misc$earg



