### Name: uqo
### Title: Fitting Unconstrained Quadratic Ordination (UQO)
### Aliases: uqo
### Keywords: models regression

### ** Examples

data(hspider)
set.seed(123)  # This leads to the global solution
hspider[,1:6] = scale(hspider[,1:6]) # Standardized environmental vars
p1 = cqo(cbind(Alopacce, Alopcune, Alopfabr, Arctlute, Arctperi,
               Auloalbi, Pardlugu, Pardmont, Pardnigr, Pardpull,
               Trocterr, Zoraspin) ~
         WaterCon + BareSand + FallTwig + CoveMoss + CoveHerb + ReflLux,
         ITolerances = TRUE, fam = poissonff, data = hspider, 
         Crow1positive=TRUE, Bestof=3, trace=FALSE)
if(deviance(p1) > 1589.0) stop("suboptimal fit obtained")

set.seed(111)
up1 = uqo(cbind(Alopacce, Alopcune, Alopfabr, Arctlute, Arctperi,
                Auloalbi, Pardlugu, Pardmont, Pardnigr, Pardpull,
                Trocterr, Zoraspin) ~ 1,
          family = poissonff, data = hspider,
          ITolerances = TRUE,
          Crow1positive = TRUE, lvstart = lv(p1))
if(deviance(up1) > 1310.0) stop("suboptimal fit obtained")

## Not run: 
##D nos = ncol(up1@y) # Number of species
##D clr = (1:(nos+1))[-7]  # to omit yellow
##D lvplot(up1, las=1, y=TRUE, pch=1:nos, scol=clr, lcol=clr, 
##D        pcol=clr, llty=1:nos, llwd=2)
##D legend(x=2, y=135, dimnames(up1@y)[[2]], col=clr, lty=1:nos,
##D        lwd=2, merge=FALSE, ncol=1, x.inter=4.0, bty="l", cex=0.9)
##D 
##D # Compare the site scores between the two models
##D plot(lv(p1), lv(up1), xlim=c(-3,4), ylim=c(-3,4), las=1)
##D abline(a=0, b=-1, lty=2, col="blue", xpd=FALSE)
##D cor(lv(p1, ITol=TRUE), lv(up1))
##D 
##D # Another comparison between the constrained & unconstrained models
##D # The signs are not right so they are similar when reflected about 0 
##D par(mfrow=c(2,1))
##D persp(up1, main="Red/Blue are the constrained/unconstrained models",
##D       label=TRUE, col="blue", las=1)
##D persp(p1, add=FALSE, col="red")
##D 1-pchisq(deviance(p1) - deviance(up1), df=52-30)
## End(Not run)



