### Name: vsmooth.spline
### Title: Vector cubic smoothing spline
### Aliases: vsmooth.spline
### Keywords: regression smooth

### ** Examples

n = 20
x = 2 + 5*(n:1)/n
x[2:4] = x[5:7]      # Allow duplication
y1 = sin(x) + rnorm(n, sd=0.13)
y2 = cos(x) + rnorm(n, sd=0.13)
y3 = 1 + sin(x) + rnorm(n, sd=0.13)  # Run this for constraints
y = cbind(y1, y2, y3)
ww = cbind(rep(3,n), 4, (1:n)/n)

(fit = vsmooth.spline(x, y, w=ww, df=5))
## Not run: 
##D plot(fit) # The 1st and 3rd functions do not differ by a constant
## End(Not run)

mat = matrix(c(1,0,1, 0,1,0), 3, 2)
(fit2 = vsmooth.spline(x, y, w=ww, df=5, iconstr=mat, xconstr=mat))
# The 1st and 3rd functions do differ by a constant:
mycols = c("red","blue","red")
## Not run: 
##D plot(fit2, lcol=mycols, pcol=mycols, las=1)
## End(Not run)

p = predict(fit, x=fit@x, deriv=0)
max(abs(fit@y - p$y))  # Should be zero

par(mfrow=c(3,1))
ux = seq(1, 8, len=100)
for(d in 1:3) {
    p = predict(fit, x=ux, deriv=d)
## Not run: 
##D     matplot(p$x, p$y, type="l", main=paste("deriv =", d), lwd=2)
## End(Not run)
}



